@@ -1,4 +1,4 @@
-use get_move::Get;
+use get_move::{Chain, Get};
 
 #[test]
 fn chain() {
@@ -56,3 +56,12 @@ fn len_variants() {
     assert_eq!(c.len(), c.iter().size_hint().0);
     assert_eq!(c.len(), c.iter().size_hint().1.unwrap());
 }
+
+const CHECK_CONST_CHAIN: Chain<[usize; 2], [usize; 2]> = get_move::chain([1, 2], [2, 3]);
+
+#[test]
+fn check_const_chain() {
+    let a = [1, 2, 2, 3];
+
+    assert!(a.iter().eq(CHECK_CONST_CHAIN.iter()));
+}
